<?php

/**
 * @file
 * Winbank redirect menu items.
 */

/**
 * Hook function for succesful order.
 */
function commerce_winbank_redirect_complete() {
  $order_id = $_POST['MerchantReference'];
  $order = commerce_static_checkout_url_load_order_or_die($order_id);
  if (!isset($_SESSION['koobebe']['ticket_response'])) {
    commerce_static_checkout_url_redirect_with_error('winbank', $order, 'can not get values from session', TRUE);
  }

  $ticket_request = $_SESSION['koobebe']['ticket_request'];
  $ticket_response = $_SESSION['koobebe']['ticket_response'];

  $long_str = array();
  $long_str[]= $ticket_response['trans_ticket'];
  $long_str[] = $ticket_request['PosId'];
  $long_str[] = $ticket_request['AcquirerId'];
  $long_str[] = $ticket_request['MerchantReference'];
  $long_str[] = $_POST['ApprovalCode'];
  $long_str[] = $_POST['Parameters'];
  $long_str[] = $_POST['ResponseCode'];
  $long_str[] = $_POST['SupportReferenceID'];
  $long_str[] = $_POST['AuthStatus'];
  $long_str[] = $_POST['PackageNo'];
  $long_str[] = $_POST['StatusFlag'];
  $hash = strtoupper(hash_hmac('sha256', implode(';', $long_str), $ticket_response['trans_ticket']));

  if ($_POST['ResultCode'] != 0 ||
    !in_array($_POST['ResponseCode'], array('00', '08', '10', '11', '16'))) {
    commerce_static_checkout_url_redirect_with_error('winbank', $order, 'Wrong POST DATA', TRUE);
  }
  elseif ($hash != $_POST['HashKey']) {
    commerce_static_checkout_url_redirect_with_error('winbank', $order, 'hashes do not match ' . $hash . ' ' . $_POST['HashKey'], TRUE);
  }

  if ($_POST['ResponseCode'] == '11') {
    watchdog('commerce_winbank_redirect', 'Double charge attempted. Order id: @order_id.', array('@order_id' => $order_id), WATCHDOG_NOTICE);
  }

  // Successfull payment.
  if ($_POST['ResultCode'] == 0 && $_POST['StatusFlag'] == 'Success') {
    $payment = commerce_payment_method_instance_load('commerce_winbank_redirect|commerce_payment_commerce_winbank_redirect');
    $transaction = commerce_payment_transaction_new('commerce_winbank_redirect', $order_id);
    $transaction->currency_code = $payment['settings']['currency_code'];
    $transaction->amount = $order->commerce_order_total[LANGUAGE_NONE][0]['amount'];
    $transaction->payload[REQUEST_TIME] = $_POST;
    $transaction->status = COMMERCE_PAYMENT_STATUS_SUCCESS;
    $transaction->message = t('Payment was successful');
    commerce_payment_transaction_save($transaction);
    commerce_checkout_complete($order);
    watchdog('commerce_winbank_redirect', 'Payment received for order: @order_id.', array('@order_id' => $order_id));
    commerce_static_checkout_url_redirect_with_success('winbank', $order);
  }
}

/**
 * Hook function for order with failure.
 */
function commerce_winbank_redirect_error() {
  $order_id = $_POST['MerchantReference'];
  $order = commerce_static_checkout_url_load_order_or_die($order_id);
  $transaction = commerce_payment_transaction_new('commerce_winbank_redirect', $order_id);
  $transaction->payload[REQUEST_TIME] = $_POST;
  $transaction->status = COMMERCE_PAYMENT_STATUS_FAILURE;
  $transaction->message = $_POST['ResponseDescription'];
  commerce_payment_transaction_save($transaction);
  commerce_static_checkout_url_redirect_with_error('winbank', $order, $_POST['ResponseDescription'] . $_POST['ResultDescription']);
}

/**
 * Hook function for canceled order.
 */
function commerce_winbank_redirect_cancel() {
  $order_id = $_GET['order_id'];
  $order = commerce_static_checkout_url_load_order_or_die($order_id);
  commerce_static_checkout_url_redirect_with_cancel('winbank', $order);
}
